@@ -20,7 +20,7 @@
 #ifndef _tds_sysdep_public_h_
 #define _tds_sysdep_public_h_
 
-/* $Id: tds_sysdep_public.h.in,v 1.11.2.1 2008/01/23 08:50:16 freddy77 Exp $ */
+/* $Id: tds_sysdep_public.h.in,v 1.14 2010-09-01 08:39:38 freddy77 Exp $ */
 
 #ifdef __cplusplus
 extern "C"
@@ -31,6 +31,7 @@ extern "C"
 ** This is where platform-specific changes need to be made.
 */
 #if defined(WIN32) || defined(_WIN32) || defined(__WIN32__)
+#include <winsock2.h>
 #include <windows.h>
 #define tds_sysdep_int16_type short	/* 16-bit int */
 #define tds_sysdep_int32_type int	/* 32-bit int */
@@ -53,7 +54,7 @@ extern "C"
 #endif				/* !tds_sysdep_int32_type */
 
 #ifndef tds_sysdep_int64_type
-#define tds_sysdep_int64_type long	/* 64-bit int */
+#define tds_sysdep_int64_type long long	/* 64-bit int */
 #endif				/* !tds_sysdep_int64_type */
 
 #ifndef tds_sysdep_real32_type
@@ -65,18 +66,9 @@ extern "C"
 #endif				/* !tds_sysdep_real64_type */
 
 #ifndef tds_sysdep_intptr_type
-#define tds_sysdep_intptr_type long
+#define tds_sysdep_intptr_type int
 #endif				/* !tds_sysdep_intptr_type */
 
-#if !defined(__WIN32__) && !defined(_WIN32) && !defined(WIN32)
-typedef int TDS_SYS_SOCKET;
-#define INVALID_SOCKET -1
-#define TDS_IS_SOCKET_INVALID(s) ((s) < 0)
-#else
-typedef SOCKET TDS_SYS_SOCKET;
-#define TDS_IS_SOCKET_INVALID(s) ((s) == INVALID_SOCKET)
-#endif
-
 #if !defined(MSDBLIB) && !defined(SYBDBLIB)
 #define SYBDBLIB 1
 #endif
